import { Component, OnInit } from '@angular/core';
import {FormControl, Validators} from "@angular/forms";
import {MatDialogRef} from "@angular/material/dialog";
import {TaskgroupService} from "../../../api";
import {error} from "@angular/compiler/src/util";
import {MatSnackBar} from "@angular/material/snack-bar";

@Component({
  selector: 'app-taskgroup-creation',
  templateUrl: './taskgroup-creation.component.html',
  styleUrls: ['./taskgroup-creation.component.css']
})
export class TaskgroupCreationComponent implements OnInit {

  nameCtrl = new FormControl('', [Validators.required, Validators.maxLength(255)])
  pending: boolean = false

  constructor(private dialogRef: MatDialogRef<TaskgroupCreationComponent>,
              private taskgroupService: TaskgroupService,
              private snackbar: MatSnackBar) { }

  ngOnInit(): void {
  }

  cancel() {
    this.dialogRef.close();
  }

  save() {
    this.pending = true;
    this.taskgroupService.taskgroupsPut({
      name: this.nameCtrl.value
    }).subscribe({
      next: resp => {
        this.pending = false;
        this.dialogRef.close(resp);
      },
      error: err => {
        this.pending = false;
        if(err.status == 409) {
          this.snackbar.open("Taskgroup already exists", "", {duration: 2000});
        } else {
          this.snackbar.open("An unexpected error occured", "");
        }
      }
    })

  }
}
